buildgamm: Uses 'buildmer' to fit big generalized additive models using...

View source: R/buildmer.r

buildgammR Documentation

Uses buildmer to fit big generalized additive models using gamm from package mgcv

Description

Uses buildmer to fit big generalized additive models using gamm from package mgcv

Usage

buildgamm(
  formula,
  data = NULL,
  family = gaussian(),
  buildmerControl = buildmerControl()
)

Arguments

formula

See the general documentation under buildmer-package.

data

See the general documentation under buildmer-package.

family

See the general documentation under buildmer-package.

buildmerControl

Control arguments for buildmer — see the general documentation under buildmerControl.

Details

The fixed and random effects are to be passed as a single formula in lme4 format. This is internally split up into the appropriate fixed and random parts. Only a single grouping factor is allowed. The random-effect covariance matrix is always unstructured. If you want to use pdMat covariance structures, you must (a) not specify any lme4 random-effects term in the formula, and (b) specify your own custom random argument in the args list in buildmerControl. Note that buildgamm will merely pass this through; no term reordering or stepwise elimination is done on a user-provided random argument.

See Also

buildmerControl

Examples


library(buildmer)
model <- buildgamm(f1 ~ s(timepoint,by=following) + (following|participant) +
       s(participant,timepoint,by=following,bs='fs'),data=vowels)


buildmer documentation built on June 27, 2026, 1:06 a.m.