buildgamm4: Uses 'buildmer' to fit generalized additive models using...

View source: R/buildmer.r

buildgamm4R Documentation

Uses buildmer to fit generalized additive models using package gamm4

Description

Uses buildmer to fit generalized additive models using package gamm4

Usage

buildgamm4(
  formula,
  data = NULL,
  family = gaussian(),
  buildmerControl = buildmerControl()
)

Arguments

formula

See the general documentation under buildmer-package.

data

See the general documentation under buildmer-package.

family

See the general documentation under buildmer-package.

buildmerControl

Control arguments for buildmer — see the general documentation under buildmerControl.

Details

The fixed and random effects are to be passed as a single formula in lme4 format. This is internally split up into the appropriate fixed and random parts.

See Also

buildmerControl

Examples



library(buildmer)
if (requireNamespace('gamm4')) model <- buildgamm4(f1 ~ s(timepoint,by=following) +
       s(participant,timepoint,by=following,bs='fs'),data=vowels)


buildmer documentation built on June 27, 2026, 1:06 a.m.