| buildmer-package | R Documentation |
The buildmer package consists of a number of functions, each designed to fit specific types of models (e.g. buildmer for mixed-effects regression, buildgam for generalized additive models, buildmertree for mixed-effects-regression trees, and so forth). The common parameters shared by all (or most of) these functions are documented in buildmerControl. For function-specific details, see the documentation for each individual function.
Maintainer: Cesko C. Voeten cvoeten@gmail.com (ORCID)
Authors:
Cesko C. Voeten cvoeten@gmail.com (ORCID)
Useful links:
Report bugs at https://gitlab.com/cvoeten/buildmer/-/work_items/issues
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.