| deviation | R Documentation |
This function is an alias to contr.deviation intended to allow the C command to work for deviation-coding the same way as it does for other, base-R, contrasts.
deviation(n, contrasts = TRUE, sparse = FALSE)
n |
See |
contrasts |
See |
sparse |
See |
A matrix of deviation-coded contrasts.
contr.deviation, contr.sum
iris$Species <- C(iris$Species,deviation)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.