migrant: A very small dataset from a pilot study on sound change.

migrantR Documentation

A very small dataset from a pilot study on sound change.

Description

A very small dataset from a pilot study on sound change.

Usage

data(migrant)

Format

A standard data frame.


buildmer documentation built on June 27, 2026, 1:06 a.m.