tabulate.formula: Parses a formula into a buildmer term list

View source: R/utility.r

tabulate.formulaR Documentation

Parses a formula into a buildmer term list

Description

Parses a formula into a buildmer term list

Usage

tabulate.formula(formula, group = NULL)

Arguments

formula

A formula.

group

A character vector of regular expressions. Terms matching the same regular expression are assigned the same block, and will be evaluated together in buildmer functions.

Value

A buildmer term list, which is just a normal data frame.

See Also

buildmer-package

Examples

form <- diag(f1 ~ (vowel1+vowel2+vowel3+vowel4)*timepoint*following +
             ((vowel1+vowel2+vowel3+vowel4)*timepoint*following|participant) + (timepoint|word))
tabulate.formula(form)
tabulate.formula(form,group='vowel[1-4]')

buildmer documentation built on June 27, 2026, 1:06 a.m.